Class: RspecSprint::Finding

Inherits:
Struct
  • Object
show all
Defined in:
lib/rspec_sprint/finding.rb

Overview

One diagnosis + prescription. ‘score` is the ROI/severity used by the Ranker to order findings (higher = more dominant). A rule returns a Finding when it fires, or nil when it is below threshold (signal-gated output, design D8).

Instance Attribute Summary collapse

Instance Attribute Details

#doc_urlObject

Returns the value of attribute doc_url

Returns:

  • (Object)

    the current value of doc_url



7
8
9
# File 'lib/rspec_sprint/finding.rb', line 7

def doc_url
  @doc_url
end

#expected_savingObject

Returns the value of attribute expected_saving

Returns:

  • (Object)

    the current value of expected_saving



7
8
9
# File 'lib/rspec_sprint/finding.rb', line 7

def expected_saving
  @expected_saving
end

#headlineObject

Returns the value of attribute headline

Returns:

  • (Object)

    the current value of headline



7
8
9
# File 'lib/rspec_sprint/finding.rb', line 7

def headline
  @headline
end

#prescriptionsObject

Returns the value of attribute prescriptions

Returns:

  • (Object)

    the current value of prescriptions



7
8
9
# File 'lib/rspec_sprint/finding.rb', line 7

def prescriptions
  @prescriptions
end

#rule_idObject

Returns the value of attribute rule_id

Returns:

  • (Object)

    the current value of rule_id



7
8
9
# File 'lib/rspec_sprint/finding.rb', line 7

def rule_id
  @rule_id
end

#scoreObject

Returns the value of attribute score

Returns:

  • (Object)

    the current value of score



7
8
9
# File 'lib/rspec_sprint/finding.rb', line 7

def score
  @score
end