Class: RspecSprint::Finding
- Inherits:
-
Struct
- Object
- Struct
- RspecSprint::Finding
- Defined in:
- lib/rspec_sprint/finding.rb
Overview
One diagnosis + prescription. ‘score` is the ROI/severity used by the Ranker to order findings (higher = more dominant). A rule returns a Finding when it fires, or nil when it is below threshold (signal-gated output, design D8).
Instance Attribute Summary collapse
-
#doc_url ⇒ Object
Returns the value of attribute doc_url.
-
#expected_saving ⇒ Object
Returns the value of attribute expected_saving.
-
#headline ⇒ Object
Returns the value of attribute headline.
-
#prescriptions ⇒ Object
Returns the value of attribute prescriptions.
-
#rule_id ⇒ Object
Returns the value of attribute rule_id.
-
#score ⇒ Object
Returns the value of attribute score.
Instance Attribute Details
#doc_url ⇒ Object
Returns the value of attribute doc_url
7 8 9 |
# File 'lib/rspec_sprint/finding.rb', line 7 def doc_url @doc_url end |
#expected_saving ⇒ Object
Returns the value of attribute expected_saving
7 8 9 |
# File 'lib/rspec_sprint/finding.rb', line 7 def expected_saving @expected_saving end |
#headline ⇒ Object
Returns the value of attribute headline
7 8 9 |
# File 'lib/rspec_sprint/finding.rb', line 7 def headline @headline end |
#prescriptions ⇒ Object
Returns the value of attribute prescriptions
7 8 9 |
# File 'lib/rspec_sprint/finding.rb', line 7 def prescriptions @prescriptions end |
#rule_id ⇒ Object
Returns the value of attribute rule_id
7 8 9 |
# File 'lib/rspec_sprint/finding.rb', line 7 def rule_id @rule_id end |
#score ⇒ Object
Returns the value of attribute score
7 8 9 |
# File 'lib/rspec_sprint/finding.rb', line 7 def score @score end |